@@ -21,19 +21,22 @@ static logical c_false = FALSE_;
 /* Subroutine */ int sgtnxv_(integer *n, real *vpx, real *vpy, integer *itpat,
 	 integer *icolor)
 {
+    static integer ifcidx;
     static logical lfcatr;
-    extern /* Subroutine */ int swqfcc_(logical *), msgdmp_(char *, char *, 
-	    char *, ftnlen, ftnlen, ftnlen), swsfcm_(logical *), swslcl_(
-	    integer *);
+    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), swqfcc_(
+	    logical *), msgdmp_(char *, char *, char *, ftnlen, ftnlen, 
+	    ftnlen), swsfcm_(logical *), swslcl_(integer *);
     static integer itpatx;
     extern /* Subroutine */ int sztncl_(void), swstcl_(integer *), sztnop_(
 	    integer *), sztnzv_(integer *, real *, real *);
+    static integer itpatxi;
 
     /* Parameter adjustments */
     --vpy;
     --vpx;
 
     /* Function Body */
+    sgiget_("IFCIDX", &ifcidx, (ftnlen)6);
     swqfcc_(&lfcatr);
     if (! lfcatr) {
 	msgdmp_("M", "SGTNXV", "FULL COLOR MODE IS NOT SUPPORTED.", (ftnlen)1,
@@ -55,7 +58,7 @@ static logical c_false = FALSE_;
     swsfcm_(&c_true);
     swstcl_(icolor);
     swslcl_(icolor);
-    itpatx = *itpat % 1000 + 999000;
+    itpatxi = ifcidx * 1000 + *itpat % 1000;
     sztnop_(&itpatx);
     sztnzv_(n, &vpx[1], &vpy[1]);
     sztncl_();
