@@ -19,7 +19,7 @@ static integer c__100 = 100;
 /* ----------------------------------------------------------------------- */
 /*     TONE PATTERN ATTRIBUTE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szstni_0_(int n__, integer *itpat)
 {
@@ -39,7 +39,7 @@ static integer c__100 = 100;
     static logical lhard;
     static integer icpat[100];
     static logical lcl2tn;
-    static integer ibgcli;
+    static integer ibgcli, ifcidx;
     static logical lclatr;
     extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
 	    char *, logical *, ftnlen), msgdmp_(char *, char *, char *, 
@@ -63,6 +63,7 @@ static integer c__100 = 100;
 /*     / INITIALIZE / */
     itpatz = *itpat;
     sgiget_("IBGCLI", &ibgcli, (ftnlen)6);
+    sgiget_("IFCIDX", &ifcidx, (ftnlen)6);
     if (lfrst) {
 	swqtnc_(&ltnatr);
 	swqclc_(&lclatr);
@@ -112,6 +113,7 @@ static integer c__100 = 100;
 		    msgdmp_("W", "SWGTON", cmsg, (ftnlen)1, (ftnlen)6, (
 			    ftnlen)80);
 		}
+	    } else if (lc == 999) {
 	    } else {
 		s_copy(cmsg, "COLOR NUMBER ## IS NOT DEFINED IN CL2TNMAP.", (
 			ftnlen)80, (ftnlen)43);
@@ -132,7 +134,7 @@ static integer c__100 = 100;
 	}
 	itpaty = itpnmy + itcliy * 1000;
     }
-    if (itpnmy == 999) {
+    if (itpnmy == ifcidx) {
 	lhard = TRUE_;
     }
     szstmd_(&lhard);
